*******************
Aerospace Utilities
*******************

About
=====

This package was rebranded in April 2022 to `flightcondition
<https://github.com/MattCJones/flightcondition>`_ and is now **DEPRECATED**.
All functionality is pulled from the newer package, so it is better to use
`flightcondition <https://github.com/MattCJones/flightcondition>`_ explicitly.

Author
======

Matthew C. Jones <matt.c.jones.aoe@gmail.com>

Installation
============

Install Commands
----------------

Install using the :code:`pip` package-management system.  The easiest method is to
open the terminal and run:

.. code-block:: bash

    pip install aeroutils

Alternatively, manually download the `source code
<https://github.com/MattCJones/aeroutils>`_, unpack, and run:

.. code-block:: bash

    pip install <path/to/aeroutils>

Dependencies
------------

* `numpy <https://numpy.org>`_: widely-used package for scientific computing.
* `pint <https://pint.readthedocs.io>`_: package for dealing with units.

Usage
=====
See `flightcondition <https://github.com/MattCJones/flightcondition>`_ for
up-to-date documentation, since this package is now **DEPRECATED**.

.. code-block:: python

    from aeroutils import *


License
=======

:code:`aeroutils` is licensed under the MIT LICENSE. See the `LICENSE <https://github.com/MattCJones/aeroutils/blob/main/LICENSE>`_ document.

Disclaimer
==========
The software is provided "as is", without warranty of any kind, express or
implied, including but not limited to the warranties of merchantability,
fitness for a particular purpose and noninfringement. In no event shall the
authors or copyright holders be liable for any claim, damages or other
liability, whether in an action of contract, tort or otherwise, arising from,
out of or in connection with the software or the use or other dealings in the
software.
